# test script and tools for DI-1000U strain gauge
import serial
import timeit


class DI1000U:
    def __init__(self, port=""):
        self.port = port
        self.ser = None

    def connect(self):
        self.ser = serial.Serial(self.port, timeout=0.1)

    def get_reading(self):
        self.ser.write(b"W\r\n")
        response = self.ser.read_until(b"\r\n")
        strain = float(response.rstrip(b"\r\n").lstrip())
        return strain


if __name__ == "__main__":
    di = DI1000U("/dev/cu.usbserial-AU04XO7N")
    di.connect()
    readings = 1000
    # print(di.get_reading())
    t = timeit.timeit(lambda: di.get_reading(), number=readings)
    print(f"ran get_reading {readings} times")
    print(f"total time: {t}s ({t/readings}s per loop)")
