"""
fakeGPIO.py
Mockup to simulate the RPi.GPIO class
"""

import threading
import functools

BOARD = 0
BCM = 1

OUT = 2
IN = 3

HIGH = 4
LOW = 5

_mode = BCM
_pin_modes = dict()
_pin_states = dict()

_lock = threading.RLock()


def _with_lock(func):
    @functools.wraps(func)
    def wrapper(*args):
        with _lock:
            func(*args)

    return wrapper


@_with_lock
def setmode(mode):
    _mode = mode


@_with_lock
def setup(pin, mode):
    _pin_modes[pin] = mode


@_with_lock
def output(pin, state):
    assert _pin_modes.get(pin, IN) == OUT
    _pin_states[pin] = state
    print(f"{pin} set {'HIGH' if state == HIGH else 'LOW'}")


@_with_lock
def input(pin):
    assert _pin_modes.get(pin, IN) == IN
    return _pin_states.get(pin, LOW) == HIGH


@_with_lock
def cleanup():
    pass
