from ssa.alarm.lightstack import LightStack, Channel
import time


def test_on_off():
    l = LightStack()
    for channel in l.enumerate_channels():
        l.on(channel)
        assert l.get(channel) == LightStack.ON
        l.off(channel)
        assert l.get(channel) == LightStack.OFF
    l.cleanup()


def test_toggle():
    l = LightStack()
    l.on(Channel.White)
    assert l.get(Channel.White) == LightStack.ON
    l.toggle(Channel.White)
    assert l.get(Channel.White) == LightStack.OFF
    l.toggle(Channel.White)
    assert l.get(Channel.White) == LightStack.ON
    l.cleanup()


def test_blinker():
    l = LightStack()
    assert l.get(Channel.White) == LightStack.OFF
    l.start_blink(0.2, Channel.White)
    l.start_blink(0.1, Channel.Red)
    time.sleep(0.3)
    assert l.get(Channel.White) == LightStack.ON
    time.sleep(0.2)
    assert l.get(Channel.White) == LightStack.OFF
    time.sleep(0.2)
    assert l.get(Channel.White) == LightStack.ON
    l.stop_blink(Channel.White)
    time.sleep(0.1)
    assert l.get(Channel.White) == LightStack.OFF
    # make sure we can launch another timer and it works
    l.start_blink(0.1, Channel.White)
    time.sleep(0.15)
    assert l.get(Channel.White) == LightStack.ON
    time.sleep(0.1)
    assert l.get(Channel.White) == LightStack.OFF
    l.cleanup()


def test_cleanup():
    l = LightStack()
    l.on(Channel.Green)
    l.on(Channel.Yellow)
    l.start_blink(0.1, Channel.White)
    l.start_blink(0.1, Channel.Red)
    time.sleep(0.5)
    l.cleanup()
    for channel in l.enumerate_channels():
        assert l.get(channel) == LightStack.OFF
