# flow-meter arduino usb

import serial
import signal
import time
from threading import Event
from threading import Timer
from ssa.influxdb.influxdb_bridge import InfluxDBBridge

# device names
DEVICE_NAME = "/dev/serial/by-id/usb-Arduino_LLC_Arduino_Nano_Every_A7F456E6515146544E4B2020FF09194E-if00"
# how are we labeling the meters
METER_NAME_MAP = ["A", "B"]

DEBUG = False


def dprint(arg):
    if DEBUG:
        print(arg)


class Monitor:
    def __init__(self):
        # setup influxdb bridge
        # exit flag
        self.exit_flag = Event()
        # open serial port
        # timeout=None should be a infinitely blocking call for reads
        dprint("opening serial device")
        self.dev = serial.Serial(DEVICE_NAME, timeout=None)
        # create influxdb bridge client
        self.idb = InfluxDBBridge()
        dprint("flow meter monitor initialized")

    # blocking polling loop
    def poll(self):
        dprint("entering infinite polling loop")
        # as long as the exit flag isn't set
        while not self.exit_flag.is_set():
            resp = self.dev.readline()
            flow_rate_strings = resp.rstrip(b"\n").decode().split(" ")
            self.injest_data(flow_rate_strings)

    def start_monitor(self):
        self.idb.connect()
        dprint("monitor running")
        self.poll()

    def exit(self):
        # set exit flag
        self.exit_flag.set()

    def injest_data(self, flow_rate_strings):
        dprint("entering injest_data")

        time_ms = int(time.time() * 1000)
        json_body = []
        for meter_id, flow_rate_string in enumerate(flow_rate_strings):
            json_body.append(
                {
                    "measurement": "coolant_flow_rate",
                    "tags": {"meter_id": METER_NAME_MAP[meter_id]},
                    "time": time_ms,
                    "fields": {
                        "flow_rate": float(flow_rate_string),
                    },
                }
            )
        self.idb.commit(json_body)

    def make_json(self, maxima, time_ms):
        json_body = []

    def cancelISR(self, *args, **kwargs):
        dprint("cancelISR called")
        self.exit()


if __name__ == "__main__":
    monitor = Monitor()
    signal.signal(signal.SIGINT, monitor.cancelISR)
    monitor.start_monitor()
